<?php

defined( 'ABSPATH' ) or die;

$GLOBALS['processed_terms'] = array();
$GLOBALS['processed_posts'] = array();

require_once ABSPATH . 'wp-admin/includes/post.php';
require_once ABSPATH . 'wp-admin/includes/taxonomy.php';
require_once ABSPATH . 'wp-admin/includes/image.php';

function themify_import_post( $post ) {
	global $processed_posts, $processed_terms;

	if ( ! post_type_exists( $post['post_type'] ) ) {
		return;
	}

	/* Menu items don't have reliable post_title, skip the post_exists check */
	if( $post['post_type'] !== 'nav_menu_item' ) {
		$post_exists = post_exists( $post['post_title'], '', $post['post_date'] );
		if ( $post_exists && get_post_type( $post_exists ) == $post['post_type'] ) {
			$processed_posts[ intval( $post['ID'] ) ] = intval( $post_exists );
			return;
		}
	}

	if( $post['post_type'] == 'nav_menu_item' ) {
		if( ! isset( $post['tax_input']['nav_menu'] ) || ! term_exists( $post['tax_input']['nav_menu'], 'nav_menu' ) ) {
			return;
		}
		$_menu_item_type = $post['meta_input']['_menu_item_type'];
		$_menu_item_object_id = $post['meta_input']['_menu_item_object_id'];

		if ( 'taxonomy' == $_menu_item_type && isset( $processed_terms[ intval( $_menu_item_object_id ) ] ) ) {
			$post['meta_input']['_menu_item_object_id'] = $processed_terms[ intval( $_menu_item_object_id ) ];
		} else if ( 'post_type' == $_menu_item_type && isset( $processed_posts[ intval( $_menu_item_object_id ) ] ) ) {
			$post['meta_input']['_menu_item_object_id'] = $processed_posts[ intval( $_menu_item_object_id ) ];
		} else if ( 'custom' != $_menu_item_type ) {
			// associated object is missing or not imported yet, we'll retry later
			// $missing_menu_items[] = $item;
			return;
		}
	}

	$post_parent = ( $post['post_type'] == 'nav_menu_item' ) ? $post['meta_input']['_menu_item_menu_item_parent'] : (int) $post['post_parent'];
	$post['post_parent'] = 0;
	if ( $post_parent ) {
		// if we already know the parent, map it to the new local ID
		if ( isset( $processed_posts[ $post_parent ] ) ) {
			if( $post['post_type'] == 'nav_menu_item' ) {
				$post['meta_input']['_menu_item_menu_item_parent'] = $processed_posts[ $post_parent ];
			} else {
				$post['post_parent'] = $processed_posts[ $post_parent ];
			}
		}
	}

	/**
	 * for hierarchical taxonomies, IDs must be used so wp_set_post_terms can function properly
	 * convert term slugs to IDs for hierarchical taxonomies
	 */
	if( ! empty( $post['tax_input'] ) ) {
		foreach( $post['tax_input'] as $tax => $terms ) {
			if( is_taxonomy_hierarchical( $tax ) ) {
				$terms = explode( ', ', $terms );
				$post['tax_input'][ $tax ] = array_map( 'themify_get_term_id_by_slug', $terms, array_fill( 0, count( $terms ), $tax ) );
			}
		}
	}

	$post['post_author'] = (int) get_current_user_id();
	$post['post_status'] = 'publish';

	$old_id = $post['ID'];

	unset( $post['ID'] );
	$post_id = wp_insert_post( $post, true );
	if( is_wp_error( $post_id ) ) {
		return false;
	} else {
		$processed_posts[ $old_id ] = $post_id;

		if( isset( $post['has_thumbnail'] ) && $post['has_thumbnail'] ) {
			$placeholder = themify_get_placeholder_image();
			if( ! is_wp_error( $placeholder ) ) {
				set_post_thumbnail( $post_id, $placeholder );
			}
		}

		return $post_id;
	}
}

function themify_get_placeholder_image() {
	static $placeholder_image = null;

	if( $placeholder_image == null ) {
		if ( ! function_exists( 'WP_Filesystem' ) ) {
			require_once ABSPATH . 'wp-admin/includes/file.php';
		}
		WP_Filesystem();
		global $wp_filesystem;
		$upload = wp_upload_bits( $post['post_name'] . '.jpg', null, $wp_filesystem->get_contents( THEMIFY_DIR . '/img/image-placeholder.jpg' ) );

		if ( $info = wp_check_filetype( $upload['file'] ) )
			$post['post_mime_type'] = $info['type'];
		else
			return new WP_Error( 'attachment_processing_error', __( 'Invalid file type', 'themify' ) );

		$post['guid'] = $upload['url'];
		$post_id = wp_insert_attachment( $post, $upload['file'] );
		wp_update_attachment_metadata( $post_id, wp_generate_attachment_metadata( $post_id, $upload['file'] ) );

		$placeholder_image = $post_id;
	}

	return $placeholder_image;
}

function themify_import_term( $term ) {
	global $processed_terms;

	if( $term_id = term_exists( $term['slug'], $term['taxonomy'] ) ) {
		if ( is_array( $term_id ) ) $term_id = $term_id['term_id'];
		if ( isset( $term['term_id'] ) )
			$processed_terms[ intval( $term['term_id'] ) ] = (int) $term_id;
		return (int) $term_id;
	}

	if ( empty( $term['parent'] ) ) {
		$parent = 0;
	} else {
		$parent = term_exists( $term['parent'], $term['taxonomy'] );
		if ( is_array( $parent ) ) $parent = $parent['term_id'];
	}

	$id = wp_insert_term( $term['name'], $term['taxonomy'], array(
		'parent' => $parent,
		'slug' => $term['slug'],
		'description' => $term['description'],
	) );
	if ( ! is_wp_error( $id ) ) {
		if ( isset( $term['term_id'] ) ) {
			$processed_terms[ intval($term['term_id']) ] = $id['term_id'];
			return $term['term_id'];
		}
	}

	return false;
}

function themify_get_term_id_by_slug( $slug, $tax ) {
	$term = get_term_by( 'slug', $slug, $tax );
	if( $term ) {
		return $term->term_id;
	}

	return false;
}

function themify_undo_import_term( $term ) {
	$term_id = term_exists( $term['slug'], $term['taxonomy'] );
	if ( $term_id ) {
		if ( is_array( $term_id ) ) $term_id = $term_id['term_id'];
		if ( isset( $term_id ) ) {
			wp_delete_term( $term_id, $term['taxonomy'] );
		}
	}
}

/**
 * Determine if a post exists based on title, content, and date
 *
 * @global wpdb $wpdb WordPress database abstraction object.
 *
 * @param array $args array of database parameters to check
 * @return int Post ID if post exists, 0 otherwise.
 */
function themify_post_exists( $args = array() ) {
	global $wpdb;

	$query = "SELECT ID FROM $wpdb->posts WHERE 1=1";
	$db_args = array();

	foreach ( $args as $key => $value ) {
		$value = wp_unslash( sanitize_post_field( $key, $value, 0, 'db' ) );
		if( ! empty( $value ) ) {
			$query .= ' AND ' . $key . ' = %s';
			$db_args[] = $value;
		}
	}

	if ( !empty ( $args ) )
		return (int) $wpdb->get_var( $wpdb->prepare($query, $args) );

	return 0;
}

function themify_undo_import_post( $post ) {
	if( $post['post_type'] == 'nav_menu_item' ) {
		$post_exists = themify_post_exists( array(
			'post_name' => $post['post_name'],
			'post_modified' => $post['post_date'],
			'post_type' => 'nav_menu_item',
		) );
	} else {
		$post_exists = post_exists( $post['post_title'], '', $post['post_date'] );
	}
	if( $post_exists && get_post_type( $post_exists ) == $post['post_type'] ) {
		/**
		 * check if the post has been modified, if so leave it be
		 *
		 * NOTE: posts are imported using wp_insert_post() which modifies post_modified field
		 * to be the same as post_date, hence to check if the post has been modified,
		 * the post_modified field is compared against post_date in the original post.
		 */
		if( $post['post_date'] == get_post_field( 'post_modified', $post_exists ) ) {
			wp_delete_post( $post_exists, true ); // true: bypass trash
		}
	}
}

function themify_do_demo_import() {

	if ( isset( $GLOBALS["ThemifyBuilder_Data_Manager"] ) ) {
		remove_action( "save_post", array( $GLOBALS["ThemifyBuilder_Data_Manager"], "save_builder_text_only"), 10, 3 );
	}
$term = array (
  'term_id' => 3,
  'name' => 'Audio',
  'slug' => 'audio',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 5,
  'name' => 'Gallery',
  'slug' => 'gallery',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 6,
  'name' => 'Image',
  'slug' => 'image',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 7,
  'name' => 'Link',
  'slug' => 'link',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 9,
  'name' => 'Quote',
  'slug' => 'quote',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 10,
  'name' => 'Status',
  'slug' => 'status',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 11,
  'name' => 'Video',
  'slug' => 'video',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 25,
  'name' => 'Notes',
  'slug' => 'notes',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 44,
  'name' => 'Blog',
  'slug' => 'blog',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 47,
  'name' => 'Note',
  'slug' => 'note',
  'term_group' => 0,
  'taxonomy' => 'category',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 26,
  'name' => 'general',
  'slug' => 'general-2',
  'term_group' => 0,
  'taxonomy' => 'post_tag',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 29,
  'name' => 'music',
  'slug' => 'music',
  'term_group' => 0,
  'taxonomy' => 'post_tag',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 30,
  'name' => 'notes',
  'slug' => 'notes-2',
  'term_group' => 0,
  'taxonomy' => 'post_tag',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 33,
  'name' => 'pets',
  'slug' => 'pets',
  'term_group' => 0,
  'taxonomy' => 'post_tag',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 34,
  'name' => 'photos',
  'slug' => 'photos',
  'term_group' => 0,
  'taxonomy' => 'post_tag',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 35,
  'name' => 'updates',
  'slug' => 'updates',
  'term_group' => 0,
  'taxonomy' => 'post_tag',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 36,
  'name' => 'video',
  'slug' => 'video-2',
  'term_group' => 0,
  'taxonomy' => 'post_tag',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 41,
  'name' => 'youtube',
  'slug' => 'youtube',
  'term_group' => 0,
  'taxonomy' => 'post_tag',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 15,
  'name' => 'Footer Nav',
  'slug' => 'footer-nav',
  'term_group' => 0,
  'taxonomy' => 'nav_menu',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$term = array (
  'term_id' => 42,
  'name' => 'Main Nav',
  'slug' => 'main-nav',
  'term_group' => 0,
  'taxonomy' => 'nav_menu',
  'description' => '',
  'parent' => 0,
);

if( ERASEDEMO ) {
	themify_undo_import_term( $term );
} else {
	themify_import_term( $term );
}

$post = array (
  'ID' => 39,
  'post_date' => '2011-02-02 22:09:58',
  'post_date_gmt' => '2011-02-02 22:09:58',
  'post_content' => '<!-- p.p1 {margin: 0.0px 0.0px 12.0px 0.0px; font: 12.0px Times} -->Mauris varius fermentum velit sit amet varius. Aenean consectetur lacus tellus, sed vestibulum quam. Donec lorem lectus, posuere in pharetra at, vestibulum et magna. Ut viverra, risus eu commodo interdum, nunc ipsum mollis purpharetra eget leo. Morbi lobortis adipiscing massa tincidunt dignissim. Nulla lobortis laoreet risus, tempor accumsan sem congue vitae.',
  'post_title' => 'Sample Quote Post',
  'post_excerpt' => '',
  'post_name' => 'sample-quote-post',
  'post_modified' => '2017-08-24 07:13:04',
  'post_modified_gmt' => '2017-08-24 07:13:04',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minblr/?p=39',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'blue',
    'quote_author' => 'Themify.me',
    'quote_author_link' => 'https://themify.me',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'quote',
    'post_format' => 'post-format-quote',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 75,
  'post_date' => '2011-02-12 21:20:39',
  'post_date_gmt' => '2011-02-12 21:20:39',
  'post_content' => 'This is a link to Themify. Curabitur vitae velit ligula, vitae lobortis massa. Mauris mattis est quis dolor venenatis vitae pharetra diam gravida. Vivamus dignissim, ligula vel ultricies varius, nibh velit pretium leo, vel placerat ipsum risus luctus purus.',
  'post_title' => 'Link to Themify',
  'post_excerpt' => '',
  'post_name' => 'link-to-themify',
  'post_modified' => '2017-08-24 07:12:58',
  'post_modified_gmt' => '2017-08-24 07:12:58',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minblr/?p=5',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'green',
    'link_url' => 'https://themify.me',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'link',
    'post_format' => 'post-format-link',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 11,
  'post_date' => '2011-05-10 21:37:32',
  'post_date_gmt' => '2011-05-10 21:37:32',
  'post_content' => 'Nunc ultrices sem mollis metus rutrum non malesuada metus fermentum. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Pellentesque interdum rutrum quam, a pharetra est pulvinar ac. <!--more-->

Vestibulum congue nisl magna. Ut vulputate odio id dui convallis in adipiscing libero condimentum. Nunc et pharetra enim. Praesent pharetra, neque et luctus tempor, leo sapien faucibus leo, a dignissim turpis ipsum sed libero.',
  'post_title' => 'Vimeo Video',
  'post_excerpt' => '',
  'post_name' => 'vimeo-video',
  'post_modified' => '2017-08-24 07:12:50',
  'post_modified_gmt' => '2017-08-24 07:12:50',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minblr/?p=11',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'default',
    'video_url' => 'http://vimeo.com/6929537',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'video',
    'post_format' => 'post-format-video',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 22,
  'post_date' => '2011-04-15 21:52:14',
  'post_date_gmt' => '2011-04-15 21:52:14',
  'post_content' => 'Aenean at adipiscing urna. Suspendisse potenti. Suspendisse vitae tellus a neque commodo rutrum. Praesent ac neque vitae massa pharetra pellentesque.',
  'post_title' => 'YouTube Video',
  'post_excerpt' => '',
  'post_name' => 'youtube-video',
  'post_modified' => '2017-08-24 07:12:53',
  'post_modified_gmt' => '2017-08-24 07:12:53',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minblr/?p=22',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'yellow',
    'video_url' => 'http://www.youtube.com/watch?v=Abjx1JJO1i8',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'video',
    'post_format' => 'post-format-video',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 26,
  'post_date' => '2011-02-13 21:55:32',
  'post_date_gmt' => '2011-02-13 21:55:32',
  'post_content' => 'Aenean consectetur lacus tellus, sed vestibulum quam. Donec lorem lectus, posuere in pharetra at, vestibulum et magna. Ut viverra, risus eu commodo interdum, nunc ipsum mollis purus, ac varius ante purus sed diam.',
  'post_title' => 'My Current Status Post',
  'post_excerpt' => '',
  'post_name' => 'my-current-status-post',
  'post_modified' => '2017-08-24 07:12:56',
  'post_modified_gmt' => '2017-08-24 07:12:56',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minblr/?p=26',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'lavender',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'status',
    'post_format' => 'post-format-status',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 28,
  'post_date' => '2011-05-15 22:02:41',
  'post_date_gmt' => '2011-05-15 22:02:41',
  'post_content' => 'Aenean at adipiscing urna. Suspendisse potenti. Suspendisse vitae tellus a neque commodo rutrum. Praesent ac neque vitae massa pharetra pellentesque. In gravida arcu ut neque ornare vitae rutrum turpis vehicula. Nunc ultrices sem mollis metus rutrum non malesuada metus fermentum.

[gallery link="file" columns="1"]',
  'post_title' => 'A Photo Gallery',
  'post_excerpt' => '',
  'post_name' => 'a-photo-gallery',
  'post_modified' => '2017-08-24 07:12:48',
  'post_modified_gmt' => '2017-08-24 07:12:48',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minblr/?p=28',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'lavender',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'gallery',
    'post_format' => 'post-format-gallery',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 166,
  'post_date' => '2011-05-25 22:58:56',
  'post_date_gmt' => '2011-05-25 22:58:56',
  'post_content' => 'Cras a fringilla nunc. Suspendisse volutpat, eros congue scelerisque iaculis, magna odio sodales dui, vitae vulputate elit metus ac arcu. Mauris consequat rhoncus dolor id sagittis. Cras tortor elit, aliquet quis tincidunt eget, dignissim non tortor.',
  'post_title' => 'Another Vimeo Video',
  'post_excerpt' => '',
  'post_name' => 'another-vimeo-video',
  'post_modified' => '2017-08-24 07:12:44',
  'post_modified_gmt' => '2017-08-24 07:12:44',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/elemin/?p=166',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'default',
    'video_url' => 'http://vimeo.com/22391248',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'video',
    'post_format' => 'post-format-video',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 720,
  'post_date' => '2011-04-27 23:29:43',
  'post_date_gmt' => '2011-04-27 23:29:43',
  'post_content' => '[gallery link="file" columns="1"]

Curabitur at arcu id turpis posuere bibendum. Sed commodo mauris eget diam pretium cursus. In sagittis feugiat mauris, in ultrices mauris lacinia eu. Fusce augue velit, vulputate elementum semper congue, rhoncus adipiscing nisl. Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit.',
  'post_title' => 'Another Photo Gallery',
  'post_excerpt' => '',
  'post_name' => 'another-photo-gallery',
  'post_modified' => '2017-08-24 07:12:51',
  'post_modified_gmt' => '2017-08-24 07:12:51',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/elemin/?p=720',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'black',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'gallery',
    'post_format' => 'post-format-image',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 31,
  'post_date' => '2010-12-31 18:23:45',
  'post_date_gmt' => '2010-12-31 18:23:45',
  'post_content' => 'Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget consectetur id, posuere at ligula.',
  'post_title' => 'Lorem Ipsum',
  'post_excerpt' => '',
  'post_name' => 'lorem-ipsum',
  'post_modified' => '2017-08-24 07:13:51',
  'post_modified_gmt' => '2017-08-24 07:13:51',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'http://demo.themify.me/wumblr/?p=31',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'orange',
    'quote_author' => 'Lorem',
    'quote_author_link' => 'http://www.lipsum.com',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'quote',
    'post_format' => 'post-format-quote',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 36,
  'post_date' => '2010-12-31 18:52:04',
  'post_date_gmt' => '2010-12-31 18:52:04',
  'post_content' => 'Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget consectetur id, posuere at ligula. Vivamus imperdiet diam ac tortor tempus posuere. Curabitur at arcu id turpis posuere bibendum. Sed commodo mauris eget diam pretium cursus. In sagittis feugiat mauris, in ultrices mauris lacinia eu. Fusce augue velit, vulputate elementum semper congue, rhoncus adipiscing nisl. Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa. Mauris mattis est quis dolor venenatis vitae pharetra diam gravida. Vivamus dignissim, ligula vel ultricies varius, nibh velit pretium leo, vel placerat ipsum risus luctus purus.<!--more-->

Nullam rutrum quam ut massa ultricies sed blandit sapien fermentum. Curabitur venenatis vehicula mattis. Nunc eleifend consectetur odio sit amet viverra. Ut euismod ligula eu tellus interdum mattis ac eu nulla. Phasellus cursus, lacus quis convallis aliquet, dolor urna ullamcorper mi, eget dapibus velit est vitae nisi. Aliquam erat nulla, sodales at imperdiet vitae, convallis vel dui. Sed ultrices felis ut justo suscipit vestibulum. Pellentesque nisl nisi, vehicula vitae hendrerit vel, mattis eget mauris. Donec consequat eros eget lectus dictum sit amet ultrices neque sodales. Aliquam metus diam, mattis fringilla adipiscing at, lacinia at nulla.',
  'post_title' => 'Just a Note',
  'post_excerpt' => '',
  'post_name' => 'just-a-note',
  'post_modified' => '2017-08-24 07:13:49',
  'post_modified_gmt' => '2017-08-24 07:13:49',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'http://demo.themify.me/wumblr/?p=36',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'yellow',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'notes',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 737,
  'post_date' => '2010-12-31 20:13:15',
  'post_date_gmt' => '2010-12-31 20:13:15',
  'post_content' => '',
  'post_title' => 'Link to Themify.me',
  'post_excerpt' => '',
  'post_name' => 'link-to-themify-me',
  'post_modified' => '2017-08-24 07:13:17',
  'post_modified_gmt' => '2017-08-24 07:13:17',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'http://demo.themify.me/wumblr/?p=39',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'yellow',
    'link_url' => 'https://themify.me',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'link',
    'post_format' => 'post-format-link',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 45,
  'post_date' => '2010-12-31 21:42:43',
  'post_date_gmt' => '2010-12-31 21:42:43',
  'post_content' => '[gallery link="file" columns="1"]',
  'post_title' => 'Black &amp; White Photos',
  'post_excerpt' => '',
  'post_name' => 'black-white-photos',
  'post_modified' => '2017-08-24 07:13:16',
  'post_modified_gmt' => '2017-08-24 07:13:16',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'http://demo.themify.me/wumblr/?p=45',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'black',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'gallery',
    'post_format' => 'post-format-gallery',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 62,
  'post_date' => '2010-12-28 21:55:56',
  'post_date_gmt' => '2010-12-28 21:55:56',
  'post_content' => 'Here is my favorite YouTube video.',
  'post_title' => 'YouTube Video',
  'post_excerpt' => '',
  'post_name' => 'my-favorite-youtube-video',
  'post_modified' => '2017-08-24 07:13:56',
  'post_modified_gmt' => '2017-08-24 07:13:56',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'http://demo.themify.me/wumblr/?p=62',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'black',
    'video_url' => 'http://www.youtube.com/watch?v=NmRTreaCJXs',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'video',
    'post_tag' => 'video-2, youtube',
    'post_format' => 'post-format-video',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 66,
  'post_date' => '2010-12-30 22:07:01',
  'post_date_gmt' => '2010-12-30 22:07:01',
  'post_content' => 'I\'m getting ready for 2011. A lot of big plans.',
  'post_title' => 'New Year 2011',
  'post_excerpt' => '',
  'post_name' => 'new-year-2011',
  'post_modified' => '2017-08-24 07:13:53',
  'post_modified_gmt' => '2017-08-24 07:13:53',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'http://demo.themify.me/wumblr/?p=66',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'blue',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'status',
    'post_format' => 'post-format-status',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 196,
  'post_date' => '2010-12-31 16:53:07',
  'post_date_gmt' => '2010-12-31 16:53:07',
  'post_content' => '',
  'post_title' => 'Another Song',
  'post_excerpt' => '',
  'post_name' => 'another-song',
  'post_modified' => '2017-08-24 07:13:52',
  'post_modified_gmt' => '2017-08-24 07:13:52',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'http://demo.themify.me/wumblr/?p=196',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'green',
    'audio_url' => 'https://themify.me/demo/themes/wumblr/files/2010/12/katy2.mp3',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'audio',
    'post_tag' => 'music',
    'post_format' => 'post-format-audio',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 218,
  'post_date' => '2010-12-30 17:04:29',
  'post_date_gmt' => '2010-12-30 17:04:29',
  'post_content' => '[gallery link="file" columns="1"]

A gallery of some stock photos.',
  'post_title' => 'Another Gallery',
  'post_excerpt' => '',
  'post_name' => 'another-gallery',
  'post_modified' => '2017-08-24 07:13:54',
  'post_modified_gmt' => '2017-08-24 07:13:54',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'http://demo.themify.me/wumblr/?p=218',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'violet',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'gallery',
    'post_tag' => 'photos',
    'post_format' => 'post-format-gallery',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 122,
  'post_date' => '2011-01-04 18:25:09',
  'post_date_gmt' => '2011-01-04 18:25:09',
  'post_content' => '',
  'post_title' => 'Vimeo Video',
  'post_excerpt' => '',
  'post_name' => 'vimeo-video-2',
  'post_modified' => '2017-08-24 07:13:14',
  'post_modified_gmt' => '2017-08-24 07:13:14',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'http://demo.themify.me/wumblr/?p=122',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'black',
    'video_url' => 'http://vimeo.com/6284199',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'video',
    'post_tag' => 'video-2',
    'post_format' => 'post-format-video',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 147,
  'post_date' => '2011-01-05 06:08:42',
  'post_date_gmt' => '2011-01-05 06:08:42',
  'post_content' => 'Mauris mattis est quis dolor venenatis vitae pharetra diam ligula vel ultricies varius, nibh velit pretium leo, vel placerat ipsum risus luctus purus.',
  'post_title' => 'Another Status Post',
  'post_excerpt' => '',
  'post_name' => 'another-status-post',
  'post_modified' => '2017-08-24 07:13:12',
  'post_modified_gmt' => '2017-08-24 07:13:12',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'http://demo.themify.me/wumblr/?p=147',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'yellow',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'status',
    'post_tag' => 'updates',
    'post_format' => 'post-format-status',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 738,
  'post_date' => '2011-01-05 16:48:12',
  'post_date_gmt' => '2011-01-05 16:48:12',
  'post_content' => '<!-- p.p1 {margin: 0.0px 0.0px 12.0px 0.0px; font: 12.0px Times} -->Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget consectetur id, posuere at ligula. Vivamus imperdiet diam ac tortor tempus posuere. Curabitur at arcu id turpis posuere bibendum. Sed commodo mauris eget diam pretium cursus. In sagittis feugiat mauris, in ultrices mauris lacinia eu. Fusce augue velit, vulputate elementum semper congue, rhoncus adipiscing nisl.<!--more-->

Nullam rutrum quam ut massa ultricies sed blandit sapien fermentum. Curabitur venenatis vehicula mattis. Nunc eleifend consectetur odio sit amet viverra. Ut euismod ligula eu tellus interdum mattis ac eu nulla. Phasellus cursus, lacus quis convallis aliquet, dolor urna ullamcorper mi, eget dapibus velit est vitae nisi. Aliquam erat nulla, sodales at imperdiet vitae, convallis vel dui. Sed ultrices felis ut justo suscipit vestibulum. Pellentesque nisl nisi, vehicula vitae hendrerit vel, mattis eget mauris. Donec consequat eros eget lectus dictum sit amet ultrices neque sodales. Aliquam metus diam, mattis fringilla adipiscing at, lacinia at nulla.',
  'post_title' => 'Another Quick Notes',
  'post_excerpt' => '',
  'post_name' => 'another-quick-notes',
  'post_modified' => '2017-08-24 07:13:10',
  'post_modified_gmt' => '2017-08-24 07:13:10',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'http://demo.themify.me/wumblr/?p=183',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'blue',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'notes',
    'post_tag' => 'general-2, notes-2',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 214,
  'post_date' => '2011-01-05 17:02:11',
  'post_date_gmt' => '2011-01-05 17:02:11',
  'post_content' => 'Say hi to Wumblr',
  'post_title' => 'Welcome to Wumblr',
  'post_excerpt' => '',
  'post_name' => 'welcome-to-wumblr',
  'post_modified' => '2017-08-24 07:13:08',
  'post_modified_gmt' => '2017-08-24 07:13:08',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'http://demo.themify.me/wumblr/?p=214',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'pink',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'status',
    'post_tag' => 'updates',
    'post_format' => 'post-format-status',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 15,
  'post_date' => '2011-02-01 21:42:10',
  'post_date_gmt' => '2011-02-01 21:42:10',
  'post_content' => 'Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget consectetur id, posuere at ligula. Vivamus imperdiet diam ac tortor tempus posuere. Curabitur at arcu id turpis posuere bibendum. Sed commodo mauris eget diam pretium cursus. In sagittis feugiat mauris, in ultrices mauris lacinia eu. Fusce augue velit, vulputate elementum semper congue, rhoncus adipiscing nisl.<!--more-->

Nullam rutrum quam ut massa ultricies sed blandit sapien fermentum. Curabitur venenatis vehicula mattis. Nunc eleifend consectetur odio sit amet viverra. Ut euismod ligula eu tellus interdum mattis ac eu nulla. Phasellus cursus, lacus quis convallis aliquet, dolor urna ullamcorper mi, eget dapibus velit est vitae nisi. Aliquam erat nulla, sodales at imperdiet vitae, convallis vel dui. Sed ultrices felis ut justo suscipit vestibulum. Pellentesque nisl nisi, vehicula vitae hendrerit vel, mattis eget mauris. Donec consequat eros eget lectus dictum sit amet ultrices neque sodales. Aliquam metus diam, mattis fringilla adipiscing at, lacinia at nulla.',
  'post_title' => 'A Note With More Tag',
  'post_excerpt' => '',
  'post_name' => 'a-note-with-more-tag',
  'post_modified' => '2017-08-24 07:13:05',
  'post_modified_gmt' => '2017-08-24 07:13:05',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minblr/?p=15',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'note',
    'post_format' => 'post-format-aside',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 885,
  'post_date' => '2011-02-02 22:09:58',
  'post_date_gmt' => '2011-02-02 22:09:58',
  'post_content' => '<!-- p.p1 {margin: 0.0px 0.0px 12.0px 0.0px; font: 12.0px Times} -->Mauris varius fermentum velit sit amet varius. Aenean consectetur lacus tellus, sed vestibulum quam. Donec lorem lectus, posuere in pharetra at, vestibulum et magna. Ut viverra, risus eu commodo interdum, nunc ipsum mollis purpharetra eget leo. Morbi lobortis adipiscing massa tincidunt dignissim. Nulla lobortis laoreet risus, tempor accumsan sem congue vitae.',
  'post_title' => 'Sample Quote Post',
  'post_excerpt' => '',
  'post_name' => 'sample-quote-post-2',
  'post_modified' => '2017-08-24 07:13:02',
  'post_modified_gmt' => '2017-08-24 07:13:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minblr/?p=39',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'default',
    'quote_author' => 'Themify.me',
    'quote_author_link' => 'https://themify.me',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'quote',
    'post_format' => 'post-format-quote',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 48,
  'post_date' => '2011-02-14 23:30:53',
  'post_date_gmt' => '2011-02-14 23:30:53',
  'post_content' => '<!-- p.p1 {margin: 0.0px 0.0px 12.0px 0.0px; font: 12.0px Times} -->Donec facilisis diam sed arcu cursus suscipit. Mauris varius fermentum velit sit amet varius. Aenean consectetur lacus tellus, sed vestibulum quam. Donec lorem lectus, posuere in pharetra at, vestibulum et magna. Ut viverra, risus eu commodo interdum, nunc ipsum mollis purus, ac varius ante purus sed diam. Vivamus in risus non lacus vehicula vestibulum. In magna leo, malesuada eget pulvinar ut, pellentesque a arcu. Praesent rutrum feugiat nibh elementum posuere. Nulla volutpat porta enim vel consectetur. Etiam orci eros, blandit nec egestas eget, pharetra eget leo. Morbi lobortis adipiscing massa tincidunt dignissim. Nulla lobortis laoreet risus, tempor accumsan sem congue vitae.',
  'post_title' => 'Regular Blog Post',
  'post_excerpt' => '',
  'post_name' => 'regular-blog-post',
  'post_modified' => '2017-08-24 07:12:55',
  'post_modified_gmt' => '2017-08-24 07:12:55',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minblr/?p=48',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 82,
  'post_date' => '2011-02-01 19:19:19',
  'post_date_gmt' => '2011-02-01 19:19:19',
  'post_content' => 'Cras ultricies cursus nisl, eget congue tellus consequat nec. Cras id nibh neque, eu dignissim orci. Aenean at adipiscing urna. Suspendisse potenti. Suspendisse vitae tellus a neque commodo rutrum. Praesent ac neque vitae massa pharetra pellentesque. Pellentesque vestibulum elit at metus venenatis non faucibus massa egestas. Suspendisse nisl leo, cursus non interdum a, consequat sed sapien. Duis at est mi, sit amet placerat lectus. Nulla facilisi. Quisque vulputate ante justo, quis malesuada arcu. Morbi id elit dolor, vitae scelerisque dui. Donec facilisis diam sed arcu cursus suscipit.

<!--more-->

Donec lorem lectus, posuere in pharetra at, vestibulum et magna. Ut viverra, risus eu commodo interdum, nunc ipsum mollis purus, ac varius ante purus sed diam. Vivamus in risus non lacus vehicula vestibulum. In magna leo, malesuada eget pulvinar ut, pellentesque a arcu. Praesent rutrum feugiat nibh elementum posuere. Nulla volutpat porta enim vel consectetur.',
  'post_title' => 'Hello Feb',
  'post_excerpt' => '',
  'post_name' => 'hello-march',
  'post_modified' => '2017-08-24 07:13:07',
  'post_modified_gmt' => '2017-08-24 07:13:07',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minblr/?p=82',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'default',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'blog',
    'post_format' => 'post-format-aside',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 887,
  'post_date' => '2011-05-20 23:15:05',
  'post_date_gmt' => '2011-05-20 23:15:05',
  'post_content' => 'Aenean at adipiscing urna. Suspendisse potenti. Suspendisse vitae tellus a neque commodo rutrum. Praesent ac neque vitae massa pharetra pellentesque. Pellentesque vestibulum elit at metus venenatis non faucibus massa egestas. <!--more-->

Suspendisse nisl leo, cursus non interdum a, consequat sed sapien. Duis at est mi, sit amet placerat lectus. Nulla facilisi. Quisque vulputate ante justo, quis malesuada arcu. Morbi id elit dolor, vitae scelerisque dui.',
  'post_title' => 'Tilt Shift Image',
  'post_excerpt' => '',
  'post_name' => 'tilt-shift-image',
  'post_modified' => '2017-08-24 07:12:46',
  'post_modified_gmt' => '2017-08-24 07:12:46',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/elemin/?p=175',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'orange',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
    'builder_switch_frontend' => '0',
  ),
  'tax_input' => 
  array (
    'category' => 'image',
    'post_format' => 'post-format-image',
  ),
  'has_thumbnail' => true,
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 913,
  'post_date' => '2011-02-02 22:09:58',
  'post_date_gmt' => '2011-02-02 22:09:58',
  'post_content' => '<!-- p.p1 {margin: 0.0px 0.0px 12.0px 0.0px; font: 12.0px Times} -->Mauris varius fermentum velit sit amet varius. Aenean consectetur lacus tellus, sed vestibulum quam. Donec lorem lectus, posuere in pharetra at, vestibulum et magna. Ut viverra, risus eu commodo interdum, nunc ipsum mollis purpharetra eget leo. Morbi lobortis adipiscing massa tincidunt dignissim. Nulla lobortis laoreet risus, tempor accumsan sem congue vitae.',
  'post_title' => 'Sample Quote Post',
  'post_excerpt' => '',
  'post_name' => 'sample-quote-post-3',
  'post_modified' => '2017-08-24 07:13:00',
  'post_modified_gmt' => '2017-08-24 07:13:00',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minblr/?p=39',
  'menu_order' => 0,
  'post_type' => 'post',
  'meta_input' => 
  array (
    'layout' => 'default',
    'content_width' => 'default_width',
    'post_color' => 'default',
    'quote_author' => 'Themify.me',
    'quote_author_link' => 'https://themify.me',
    'hide_post_title' => 'default',
    'unlink_post_title' => 'default',
    'hide_post_meta' => 'default',
    'hide_post_date' => 'default',
    'hide_post_image' => 'default',
  ),
  'tax_input' => 
  array (
    'category' => 'quote',
    'post_format' => 'post-format-quote',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 767,
  'post_date' => '2011-09-07 22:18:55',
  'post_date_gmt' => '2011-09-07 22:18:55',
  'post_content' => '',
  'post_title' => 'Home',
  'post_excerpt' => '',
  'post_name' => 'custom-frontpage',
  'post_modified' => '2017-08-24 07:14:57',
  'post_modified_gmt' => '2017-08-24 07:14:57',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/grido/?page_id=767',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'yes',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid4',
    'posts_per_page' => '14',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 161,
  'post_date' => '2011-04-08 21:10:45',
  'post_date_gmt' => '2011-04-08 21:10:45',
  'post_content' => '',
  'post_title' => 'Map',
  'post_excerpt' => '',
  'post_name' => 'map',
  'post_modified' => '2017-08-25 02:53:06',
  'post_modified_gmt' => '2017-08-25 02:53:06',
  'post_content_filtered' => '',
  'post_parent' => 5,
  'guid' => 'https://themify.me/demo/themes/minblr/?page_id=161',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
    '_themify_builder_settings_json' => '[{\\"row_order\\":\\"0\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col3-2 first\\",\\"modules\\":[{\\"mod_name\\":\\"map\\",\\"mod_settings\\":{\\"map_display_type\\":\\"dynamic\\",\\"address_map\\":\\"Yonge St. and Eglinton Ave, Toronto, Ontario, Canada\\",\\"zoom_map\\":\\"15\\",\\"w_map\\":\\"100\\",\\"unit_w\\":\\"%\\",\\"h_map\\":\\"600\\",\\"unit_h\\":\\"px\\",\\"b_style_map\\":\\"solid\\",\\"type_map\\":\\"ROADMAP\\",\\"scrollwheel_map\\":\\"disable\\",\\"draggable_map\\":\\"enable\\",\\"draggable_disable_mobile_map\\":\\"yes\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"solid\\",\\"border_right_style\\":\\"solid\\",\\"border_bottom_style\\":\\"solid\\",\\"border_left_style\\":\\"solid\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"styling\\":[]},{\\"column_order\\":\\"1\\",\\"grid_class\\":\\"col3-1 last\\",\\"modules\\":[{\\"mod_name\\":\\"text\\",\\"mod_settings\\":{\\"content_text\\":\\"<h3>Direction</h3><p>We are located at Aliquam faucibus turpis at libero consectetur euismod. Nam nunc lectus, congue non egestas quis, condimentum ut arcu. Nulla placerat, tortor non egestas rutrum, mi turpis adipiscing dui, et mollis turpis tortor vel orci. Cras a fringilla nunc. Suspendisse volutpat, eros congue scelerisque iaculis, magna odio sodales dui, vitae vulputate elit metus ac arcu.</p><h3>Address</h3><p>123 Street Name,<br /> City, Province<br /> 23446</p><h3>Phone</h3><p>236-298-2828</p><h3>Hours</h3><p>Mon - Fri : 11:00am - 10:00pm<br /> Sat : 11:00am - 2:00pm<br /> Sun : 12:00am - 11:00pm</p>\\",\\"column_divider_style\\":\\"solid\\",\\"checkbox_padding_apply_all\\":\\"padding\\",\\"checkbox_margin_apply_all\\":\\"margin\\",\\"border_top_style\\":\\"solid\\",\\"border_right_style\\":\\"solid\\",\\"border_bottom_style\\":\\"solid\\",\\"border_left_style\\":\\"solid\\",\\"checkbox_border_apply_all\\":\\"border\\"}}],\\"styling\\":[]}],\\"column_alignment\\":\\"\\",\\"styling\\":[]},{\\"row_order\\":\\"1\\",\\"cols\\":[{\\"column_order\\":\\"0\\",\\"grid_class\\":\\"col-full first last\\",\\"modules\\":[],\\"styling\\":[]}],\\"styling\\":[]}]',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 542,
  'post_date' => '2011-04-03 00:52:10',
  'post_date_gmt' => '2011-04-03 00:52:10',
  'post_content' => '',
  'post_title' => 'Fullwidth',
  'post_excerpt' => '',
  'post_name' => 'fullwidth',
  'post_modified' => '2017-08-24 07:15:04',
  'post_modified_gmt' => '2017-08-24 07:15:04',
  'post_content_filtered' => '',
  'post_parent' => 409,
  'guid' => 'https://themify.me/demo/themes/bizco/?page_id=542',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 547,
  'post_date' => '2011-04-03 00:53:59',
  'post_date_gmt' => '2011-04-03 00:53:59',
  'post_content' => '',
  'post_title' => 'Full - 4 Column',
  'post_excerpt' => '',
  'post_name' => '4-column',
  'post_modified' => '2017-08-24 07:15:10',
  'post_modified_gmt' => '2017-08-24 07:15:10',
  'post_content_filtered' => '',
  'post_parent' => 542,
  'guid' => 'https://themify.me/demo/themes/bizco/?page_id=547',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid4',
    'posts_per_page' => '12',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 551,
  'post_date' => '2011-04-03 00:56:20',
  'post_date_gmt' => '2011-04-03 00:56:20',
  'post_content' => '',
  'post_title' => 'Full - 3 Column',
  'post_excerpt' => '',
  'post_name' => '3-column',
  'post_modified' => '2017-08-24 07:15:08',
  'post_modified_gmt' => '2017-08-24 07:15:08',
  'post_content_filtered' => '',
  'post_parent' => 542,
  'guid' => 'https://themify.me/demo/themes/bizco/?page_id=551',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid3',
    'posts_per_page' => '12',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 553,
  'post_date' => '2011-04-03 00:56:45',
  'post_date_gmt' => '2011-04-03 00:56:45',
  'post_content' => '',
  'post_title' => 'Full - 2 Column',
  'post_excerpt' => '',
  'post_name' => '2-column',
  'post_modified' => '2017-08-24 07:15:06',
  'post_modified_gmt' => '2017-08-24 07:15:06',
  'post_content_filtered' => '',
  'post_parent' => 542,
  'guid' => 'https://themify.me/demo/themes/bizco/?page_id=553',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid2',
    'posts_per_page' => '8',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 561,
  'post_date' => '2011-04-03 01:01:38',
  'post_date_gmt' => '2011-04-03 01:01:38',
  'post_content' => '',
  'post_title' => 'Sidebar Left',
  'post_excerpt' => '',
  'post_name' => 'sidebar-left',
  'post_modified' => '2017-08-24 07:15:12',
  'post_modified_gmt' => '2017-08-24 07:15:12',
  'post_content_filtered' => '',
  'post_parent' => 409,
  'guid' => 'https://themify.me/demo/themes/bizco/?page_id=561',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar1 sidebar-left',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 563,
  'post_date' => '2011-04-03 01:02:18',
  'post_date_gmt' => '2011-04-03 01:02:18',
  'post_content' => '',
  'post_title' => 'SB Left - 4 Column',
  'post_excerpt' => '',
  'post_name' => '4-column',
  'post_modified' => '2017-08-24 07:15:16',
  'post_modified_gmt' => '2017-08-24 07:15:16',
  'post_content_filtered' => '',
  'post_parent' => 561,
  'guid' => 'https://themify.me/demo/themes/bizco/?page_id=563',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar1 sidebar-left',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid4',
    'posts_per_page' => '8',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 566,
  'post_date' => '2011-04-03 01:03:05',
  'post_date_gmt' => '2011-04-03 01:03:05',
  'post_content' => '',
  'post_title' => 'SB Left - 3 Column',
  'post_excerpt' => '',
  'post_name' => '3-column',
  'post_modified' => '2017-08-24 07:15:15',
  'post_modified_gmt' => '2017-08-24 07:15:15',
  'post_content_filtered' => '',
  'post_parent' => 561,
  'guid' => 'https://themify.me/demo/themes/bizco/?page_id=566',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar1 sidebar-left',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid3',
    'posts_per_page' => '9',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 568,
  'post_date' => '2011-04-03 01:03:28',
  'post_date_gmt' => '2011-04-03 01:03:28',
  'post_content' => '',
  'post_title' => 'SB Left - 2 Column',
  'post_excerpt' => '',
  'post_name' => '2-column',
  'post_modified' => '2017-08-24 07:15:13',
  'post_modified_gmt' => '2017-08-24 07:15:13',
  'post_content_filtered' => '',
  'post_parent' => 561,
  'guid' => 'https://themify.me/demo/themes/bizco/?page_id=568',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid2',
    'posts_per_page' => '8',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 576,
  'post_date' => '2011-04-03 01:09:14',
  'post_date_gmt' => '2011-04-03 01:09:14',
  'post_content' => '',
  'post_title' => 'Sidebar Right',
  'post_excerpt' => '',
  'post_name' => 'sidebar-right',
  'post_modified' => '2017-08-24 07:15:18',
  'post_modified_gmt' => '2017-08-24 07:15:18',
  'post_content_filtered' => '',
  'post_parent' => 409,
  'guid' => 'https://themify.me/demo/themes/bizco/?page_id=576',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar1',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 578,
  'post_date' => '2011-04-03 01:09:38',
  'post_date_gmt' => '2011-04-03 01:09:38',
  'post_content' => '',
  'post_title' => 'SB Right - 4 Column',
  'post_excerpt' => '',
  'post_name' => '4-column',
  'post_modified' => '2017-08-24 07:15:25',
  'post_modified_gmt' => '2017-08-24 07:15:25',
  'post_content_filtered' => '',
  'post_parent' => 576,
  'guid' => 'https://themify.me/demo/themes/bizco/?page_id=578',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar1',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid4',
    'posts_per_page' => '8',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 580,
  'post_date' => '2011-04-03 01:10:05',
  'post_date_gmt' => '2011-04-03 01:10:05',
  'post_content' => '',
  'post_title' => 'SB Right - 3 Column',
  'post_excerpt' => '',
  'post_name' => '3-column',
  'post_modified' => '2017-08-24 07:15:21',
  'post_modified_gmt' => '2017-08-24 07:15:21',
  'post_content_filtered' => '',
  'post_parent' => 576,
  'guid' => 'https://themify.me/demo/themes/bizco/?page_id=580',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid3',
    'posts_per_page' => '9',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 582,
  'post_date' => '2011-04-03 01:10:24',
  'post_date_gmt' => '2011-04-03 01:10:24',
  'post_content' => '',
  'post_title' => 'SB Right - 2 Column',
  'post_excerpt' => '',
  'post_name' => '2-column',
  'post_modified' => '2017-08-24 07:15:20',
  'post_modified_gmt' => '2017-08-24 07:15:20',
  'post_content_filtered' => '',
  'post_parent' => 576,
  'guid' => 'https://themify.me/demo/themes/bizco/?page_id=582',
  'menu_order' => 0,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'grid2',
    'posts_per_page' => '8',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 848,
  'post_date' => '2011-07-10 23:28:47',
  'post_date_gmt' => '2011-07-10 23:28:47',
  'post_content' => '<h3>WordPress Photo Gallery</h3>
You can insert photo galleries in any post, page and even widget.

[gallery link="file" columns="1" order="DESC"]',
  'post_title' => 'Gallery',
  'post_excerpt' => '',
  'post_name' => 'gallery',
  'post_modified' => '2017-08-24 07:14:59',
  'post_modified_gmt' => '2017-08-24 07:14:59',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/suco/?page_id=848',
  'menu_order' => 1,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 409,
  'post_date' => '2010-10-08 11:15:14',
  'post_date_gmt' => '2010-10-08 11:15:14',
  'post_content' => '',
  'post_title' => 'Layouts',
  'post_excerpt' => '',
  'post_name' => 'layouts',
  'post_modified' => '2017-08-24 07:15:02',
  'post_modified_gmt' => '2017-08-24 07:15:02',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'http://demo.themify.me/bizco',
  'menu_order' => 2,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'query_category' => '0',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'display_content' => 'content',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 5,
  'post_date' => '2011-02-15 23:14:29',
  'post_date_gmt' => '2011-02-15 23:14:29',
  'post_content' => 'Download this contact plugin: <a href="http://wordpress.org/extend/plugins/contact-form-7">Contact Form 7</a>.

[contact-form 1 "Contact form 1"]',
  'post_title' => 'Contact',
  'post_excerpt' => '',
  'post_name' => 'contact',
  'post_modified' => '2017-08-24 07:15:26',
  'post_modified_gmt' => '2017-08-24 07:15:26',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/minblr/?page_id=2',
  'menu_order' => 3,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'default',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'list-post',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 408,
  'post_date' => '2010-10-06 21:16:00',
  'post_date_gmt' => '2010-10-07 01:16:00',
  'post_content' => '<h3>Buttons</h3>
[button style="orange" link="https://themify.me"]Orange[/button] [button style="blue"]Blue[/button] [button style="pink"]Pink[/button] [button style="green"]Green[/button] [button style="red"]Red[/button] [button style="black"]Black[/button]

[hr]

[button style="small"]Small[/button]

[button]Default[/button]

[button style="large"]Large[/button] [button style="xlarge"]Xlarge[/button]

[hr]

[button style="orange small"]Orange Small[/button] [button style="blue"]Blue[/button] [button style="green large"]Green Large[/button] [button style="red xlarge"]Red Xlarge[/button]

[hr]
<h3>Columns</h3>
[col grid="2-1 first"]
<h4>col 2-1</h4>
Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eg.

[/col]

[col grid="2-1"]
<h4>col 2-1</h4>
Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa.

[/col]

[hr]

[col grid="3-1 first"]
<h4>col 3-1</h4>
Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eg.

[/col]

[col grid="3-1"]
<h4>col 3-1</h4>
Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa.

[/col]

[col grid="3-1"]
<h4>col 3-1</h4>
Vivamus dignissim, ligula velt pretium leo, vel placerat ipsum risus luctus purus. Tos, sed eleifend arcu. Donec porttitor hendrerit.

[/col]

[hr]

[col grid="4-1 first"]
<h4>col 4-1</h4>
Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget co.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis mas.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Vivamus dignissim, ligula velt pretium leo, vel placerat ipsum risus luctus purus. Tos, sed eleifend arcu. Donec porttitor hendrerit diam.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Donec porttitor hendrerit diam et blandit. Curabitur vel risus eros, sed eleifend arcu. Curabitur vitae velit ligula, vitae lobortis mas.

[/col]

[hr]

[col grid="4-2 first"]
<h4>col 4-2</h4>
Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget cout rhoncus turpis augue vitae libero.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis mas.

[/col]

[col grid="4-1"]
<h4>col 4-1</h4>
Vivamus dignissim, ligula velt pretium leo, vel placerat ipsum risus luctus purus. Tos, sed eleifend arcu. Donec porttitor hendrerit diam.

[/col]
<h3>Horizontal Rules</h3>
[hr]

[hr color="pink"]

[hr color="red"]

[hr color="light-gray"]

[hr color="dark-gray"]

[hr color="black"]

[hr color="orange"]

[hr color="yellow"]

[hr color="white"]
<h3>Quote</h3>
[quote]Vivamus in risus non lacus vehicula vestibulum. In magna leo, malesuada eget pulvinar ut, pellentesque a arcu. Praesent rutrum feugiat nibh elementum posuere. Nulla volutpat porta enim vel consectetur. Etiam orci eros, blandit nec egestas eget, pharetra eget leo. Morbi lobortis adipiscing massa tincidunt dignissim. Nulla lobortis laoreet risus, tempor accumsan sem congue vitae. Cras laoreet hendrerit erat, id porttitor nunc blandit adipiscing. [/quote]
<h3>Map</h3>
[map address="Yonge St. and Eglinton Ave, Toronto, Ontario, Canada" width=100% height=400px]',
  'post_title' => 'Shortcodes',
  'post_excerpt' => '',
  'post_name' => 'shortcodes-2',
  'post_modified' => '2017-08-24 07:15:30',
  'post_modified_gmt' => '2017-08-24 07:15:30',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'http://demo.themify.me/bizco/?page_id=101',
  'menu_order' => 4,
  'post_type' => 'page',
  'meta_input' => 
  array (
    'page_layout' => 'sidebar-none',
    'content_width' => 'default_width',
    'hide_page_title' => 'default',
    'order' => 'desc',
    'orderby' => 'date',
    'layout' => 'default',
    'display_content' => 'none',
    'hide_title' => 'default',
    'unlink_title' => 'default',
    'hide_date' => 'default',
    'hide_meta' => 'default',
    'hide_image' => 'default',
    'unlink_image' => 'default',
    'hide_navigation' => 'default',
  ),
  'tax_input' => 
  array (
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 786,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '786',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/grido/?p=786',
  'menu_order' => 1,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '767',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 785,
  'post_date' => '2011-09-07 22:37:42',
  'post_date_gmt' => '2011-09-07 22:37:42',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '785',
  'post_modified' => '2013-07-17 23:44:09',
  'post_modified_gmt' => '2013-07-17 23:44:09',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/grido/?p=785',
  'menu_order' => 1,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '767',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 787,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => 'Download this contact plugin: Contact Form 7. [contact-form 1 "Contact form 1"]',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '787',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/grido/?p=787',
  'menu_order' => 2,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '5',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 914,
  'post_date' => '2012-09-12 21:32:09',
  'post_date_gmt' => '2012-09-12 21:32:09',
  'post_content' => 'Download this contact plugin: Contact Form 7. [contact-form 1 "Contact form 1"]',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '914',
  'post_modified' => '2013-07-17 23:44:09',
  'post_modified_gmt' => '2013-07-17 23:44:09',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/grido/uncategorized/914',
  'menu_order' => 2,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '5',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 734,
  'post_date' => '2011-09-07 19:30:57',
  'post_date_gmt' => '2011-09-07 19:30:57',
  'post_content' => '[col grid="3-2 first"] [map address="Yonge St. and Eglinton Ave, Toronto, Ontario, Canada" width=100% height=600px] [/col] [col grid="3-1"] Direction We are located at Aliquam faucibus turpis at libero consectetur euismod. Nam nunc lectus, congue non egestas quis, condimentum ut arcu. Nulla placerat, tortor non egestas rutrum, mi turpis adipiscing dui, et mollis turpis tortor vel orci. Cras a fringilla nunc. Suspendisse volutpat, eros congue scelerisque iaculis, magna odio sodales dui, vitae vulputate elit metus ac arcu. Address 123 Street Name, City, Province 23446 Phone 236-298-2828 Hours Mon – Fri : 11:00am – 10:00pm Sat : 11:00am – 2:00pm Sun : 12:00am – 11:00pm [/col]',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '734',
  'post_modified' => '2013-07-17 23:44:09',
  'post_modified_gmt' => '2013-07-17 23:44:09',
  'post_content_filtered' => '',
  'post_parent' => 5,
  'guid' => 'https://themify.me/demo/themes/grido/2011/09/07/734/',
  'menu_order' => 3,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '161',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 788,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => '[col grid="3-2 first"] [map address="Yonge St. and Eglinton Ave, Toronto, Ontario, Canada" width=100% height=600px] [/col] [col grid="3-1"] Direction We are located at Aliquam faucibus turpis at libero consectetur euismod. Nam nunc lectus, congue non egestas quis, condimentum ut arcu. Nulla placerat, tortor non egestas rutrum, mi turpis adipiscing dui, et mollis turpis tortor vel orci. Cras a fringilla nunc. Suspendisse volutpat, eros congue scelerisque iaculis, magna odio sodales dui, vitae vulputate elit metus ac arcu. Address 123 Street Name, City, Province 23446 Phone 236-298-2828 Hours Mon – Fri : 11:00am – 10:00pm Sat : 11:00am – 2:00pm Sun : 12:00am – 11:00pm [/col]',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '788',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 5,
  'guid' => 'https://themify.me/demo/themes/grido/?p=788',
  'menu_order' => 3,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '787',
    '_menu_item_object_id' => '161',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 790,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '790',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/grido/?p=790',
  'menu_order' => 4,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '409',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 874,
  'post_date' => '2012-09-12 21:09:20',
  'post_date_gmt' => '2012-09-12 21:09:20',
  'post_content' => '',
  'post_title' => 'Columns',
  'post_excerpt' => '',
  'post_name' => 'columns',
  'post_modified' => '2013-07-17 23:44:09',
  'post_modified_gmt' => '2013-07-17 23:44:09',
  'post_content_filtered' => '',
  'post_parent' => 542,
  'guid' => 'https://themify.me/demo/themes/grido/uncategorized/columns',
  'menu_order' => 4,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '547',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 791,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '791',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 409,
  'guid' => 'https://themify.me/demo/themes/grido/?p=791',
  'menu_order' => 5,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '790',
    '_menu_item_object_id' => '542',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 872,
  'post_date' => '2012-09-12 21:09:20',
  'post_date_gmt' => '2012-09-12 21:09:20',
  'post_content' => 'Buttons [button style="orange" link="https://themify.me"]Orange[/button] [button style="blue"]Blue[/button] [button style="pink"]Pink[/button] [button style="green"]Green[/button] [button style="red"]Red[/button] [button style="black"]Black[/button] [hr] [button style="small"]Small[/button] [button]Default[/button] [button style="large"]Large[/button] [button style="xlarge"]Xlarge[/button] [hr] [button style="orange small"]Orange Small[/button] [button style="blue"]Blue[/button] [button style="green large"]Green Large[/button] [button style="red xlarge"]Red Xlarge[/button] [hr] Columns [col grid="2-1 first"] col 2-1 Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eg. [/col] [col grid="2-1"] col 2-1 Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa. [/col] [hr] [col grid="3-1 first"] col 3-1 Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eg. [/col] [col grid="3-1"] col 3-1 Curabitur vel risus eros, sed eleifend arcu. Donec porttitor hendrerit diam et blandit. Curabitur vitae velit ligula, vitae lobortis massa. [/col] [col grid="3-1"] col 3-1 Vivamus dignissim, ligula velt pretium leo, vel placerat ipsum risus luctus purus. Tos, sed eleifend arcu. Donec porttitor hendrerit. [/col] [hr] [col grid="4-1 first"] col 4-1 Sed sagittis, elit egestas rutrum vehicula, neque dolor fringilla lacus, ut rhoncus turpis augue vitae libero. Nam risus velit, rhoncus eget co. [/col] [col grid="4-1"] col…',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '872',
  'post_modified' => '2013-07-17 23:44:09',
  'post_modified_gmt' => '2013-07-17 23:44:09',
  'post_content_filtered' => '',
  'post_parent' => 0,
  'guid' => 'https://themify.me/demo/themes/grido/uncategorized/872',
  'menu_order' => 5,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '0',
    '_menu_item_object_id' => '408',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'footer-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 792,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '792',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 542,
  'guid' => 'https://themify.me/demo/themes/grido/?p=792',
  'menu_order' => 6,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '791',
    '_menu_item_object_id' => '553',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 793,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '793',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 542,
  'guid' => 'https://themify.me/demo/themes/grido/?p=793',
  'menu_order' => 7,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '791',
    '_menu_item_object_id' => '551',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 794,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '794',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 542,
  'guid' => 'https://themify.me/demo/themes/grido/?p=794',
  'menu_order' => 8,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '791',
    '_menu_item_object_id' => '547',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 795,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '795',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 409,
  'guid' => 'https://themify.me/demo/themes/grido/?p=795',
  'menu_order' => 9,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '790',
    '_menu_item_object_id' => '561',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 796,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '796',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 561,
  'guid' => 'https://themify.me/demo/themes/grido/?p=796',
  'menu_order' => 10,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '795',
    '_menu_item_object_id' => '568',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 797,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '797',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 561,
  'guid' => 'https://themify.me/demo/themes/grido/?p=797',
  'menu_order' => 11,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '795',
    '_menu_item_object_id' => '566',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 798,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '798',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 561,
  'guid' => 'https://themify.me/demo/themes/grido/?p=798',
  'menu_order' => 12,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '795',
    '_menu_item_object_id' => '563',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 799,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '799',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 409,
  'guid' => 'https://themify.me/demo/themes/grido/?p=799',
  'menu_order' => 13,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '790',
    '_menu_item_object_id' => '576',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 800,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '800',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 576,
  'guid' => 'https://themify.me/demo/themes/grido/?p=800',
  'menu_order' => 14,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '799',
    '_menu_item_object_id' => '582',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 801,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '801',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 576,
  'guid' => 'https://themify.me/demo/themes/grido/?p=801',
  'menu_order' => 15,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '799',
    '_menu_item_object_id' => '580',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}

$post = array (
  'ID' => 802,
  'post_date' => '2011-09-07 22:38:41',
  'post_date_gmt' => '2011-09-07 22:38:41',
  'post_content' => ' ',
  'post_title' => '',
  'post_excerpt' => '',
  'post_name' => '802',
  'post_modified' => '2015-01-26 18:43:56',
  'post_modified_gmt' => '2015-01-26 18:43:56',
  'post_content_filtered' => '',
  'post_parent' => 576,
  'guid' => 'https://themify.me/demo/themes/grido/?p=802',
  'menu_order' => 16,
  'post_type' => 'nav_menu_item',
  'meta_input' => 
  array (
    '_menu_item_type' => 'post_type',
    '_menu_item_menu_item_parent' => '799',
    '_menu_item_object_id' => '578',
    '_menu_item_object' => 'page',
    '_menu_item_classes' => 
    array (
      0 => '',
    ),
  ),
  'tax_input' => 
  array (
    'nav_menu' => 'main-nav',
  ),
);

if( ERASEDEMO ) {
	themify_undo_import_post( $post );
} else {
	themify_import_post( $post );
}


function themify_import_get_term_id_from_slug( $slug ) {
	$menu = get_term_by( "slug", $slug, "nav_menu" );
	return is_wp_error( $menu ) ? 0 : (int) $menu->term_id;
}

	$widgets = get_option( "widget_themify-flickr" );
$widgets[1002] = array (
  'title' => 'Flickr Photos',
  'username' => '52839779@N02',
  'show_count' => '9',
);
update_option( "widget_themify-flickr", $widgets );

$widgets = get_option( "widget_themify-recent-comments" );
$widgets[1003] = array (
  'title' => 'Recent Comments',
  'show_count' => '3',
  'show_avatar' => 'on',
  'avatar_size' => '36',
  'excerpt_length' => '60',
);
update_option( "widget_themify-recent-comments", $widgets );

$widgets = get_option( "widget_themify-twitter" );
$widgets[1004] = array (
  'title' => 'Latest Tweets',
  'username' => 'themify',
  'show_count' => '3',
  'hide_timestamp' => NULL,
  'hide_url' => 'on',
  'show_follow' => 'on',
  'follow_text' => '→ Follow me',
);
update_option( "widget_themify-twitter", $widgets );

$widgets = get_option( "widget_themify-links" );
$widgets[1005] = array (
  'title' => '',
  'category' => '43',
  'orderby' => 'id',
  'show_count' => '10',
  'show_thumb' => 'on',
  'show_name' => NULL,
  'show_desc' => NULL,
);
update_option( "widget_themify-links", $widgets );



$sidebars_widgets = array (
  'sidebar-main' => 
  array (
    0 => 'themify-flickr-1002',
    1 => 'themify-recent-comments-1003',
    2 => 'themify-twitter-1004',
  ),
  'social-widget' => 
  array (
    0 => 'themify-links-1005',
  ),
); 
update_option( "sidebars_widgets", $sidebars_widgets );

$menu_locations = array();
$menu = get_terms( "nav_menu", array( "slug" => "main-nav" ) );
if( is_array( $menu ) && ! empty( $menu ) ) $menu_locations["main-nav"] = $menu[0]->term_id;
$menu = get_terms( "nav_menu", array( "slug" => "footer-nav" ) );
if( is_array( $menu ) && ! empty( $menu ) ) $menu_locations["footer-nav"] = $menu[0]->term_id;
set_theme_mod( "nav_menu_locations", $menu_locations );



	ob_start(); ?>a:54:{s:16:"setting-page_404";s:1:"0";s:21:"setting-webfonts_list";s:11:"recommended";s:22:"setting-default_layout";s:12:"sidebar-none";s:27:"setting-default_post_layout";s:5:"grid4";s:30:"setting-default_layout_display";s:7:"excerpt";s:25:"setting-default_more_text";s:4:"More";s:21:"setting-index_orderby";s:4:"date";s:19:"setting-index_order";s:4:"DESC";s:31:"setting-image_post_feature_size";s:5:"blank";s:32:"setting-default_page_post_layout";s:8:"sidebar1";s:38:"setting-image_post_single_feature_size";s:5:"blank";s:27:"setting-default_page_layout";s:8:"sidebar1";s:53:"setting-customizer_responsive_design_tablet_landscape";s:4:"1024";s:43:"setting-customizer_responsive_design_tablet";s:3:"768";s:43:"setting-customizer_responsive_design_mobile";s:3:"680";s:33:"setting-mobile_menu_trigger_point";s:4:"1200";s:24:"setting-gallery_lightbox";s:8:"lightbox";s:27:"setting-script_minification";s:7:"disable";s:27:"setting-page_builder_expiry";s:1:"2";s:19:"setting-entries_nav";s:8:"numbered";s:18:"setting-more_posts";s:8:"infinite";s:29:"setting-header_slider_enabled";s:2:"on";s:29:"setting-header_slider_display";s:5:"posts";s:36:"setting-header_slider_posts_category";s:1:"0";s:34:"setting-header_slider_posts_slides";s:1:"6";s:37:"setting-header_slider_default_display";s:4:"none";s:29:"setting-header_slider_visible";s:1:"4";s:26:"setting-header_slider_auto";s:1:"0";s:28:"setting-header_slider_scroll";s:1:"1";s:27:"setting-header_slider_speed";s:2:".5";s:26:"setting-header_slider_wrap";s:3:"yes";s:22:"setting-footer_widgets";s:17:"footerwidget-3col";s:27:"setting-global_feature_size";s:5:"large";s:22:"setting-link_icon_type";s:10:"image-icon";s:32:"setting-link_type_themify-link-0";s:10:"image-icon";s:33:"setting-link_title_themify-link-0";s:7:"Twitter";s:31:"setting-link_img_themify-link-0";s:91:"https://themify.me/demo/themes/grido/wp-content/themes/grido/themify/img/social/twitter.png";s:32:"setting-link_type_themify-link-1";s:10:"image-icon";s:33:"setting-link_title_themify-link-1";s:8:"Facebook";s:31:"setting-link_img_themify-link-1";s:92:"https://themify.me/demo/themes/grido/wp-content/themes/grido/themify/img/social/facebook.png";s:32:"setting-link_type_themify-link-2";s:10:"image-icon";s:33:"setting-link_title_themify-link-2";s:7:"Google+";s:31:"setting-link_img_themify-link-2";s:95:"https://themify.me/demo/themes/grido/wp-content/themes/grido/themify/img/social/google-plus.png";s:32:"setting-link_type_themify-link-3";s:10:"image-icon";s:33:"setting-link_title_themify-link-3";s:7:"YouTube";s:31:"setting-link_img_themify-link-3";s:91:"https://themify.me/demo/themes/grido/wp-content/themes/grido/themify/img/social/youtube.png";s:32:"setting-link_type_themify-link-4";s:10:"image-icon";s:33:"setting-link_title_themify-link-4";s:9:"Pinterest";s:31:"setting-link_img_themify-link-4";s:93:"https://themify.me/demo/themes/grido/wp-content/themes/grido/themify/img/social/pinterest.png";s:22:"setting-link_field_ids";s:171:"{"themify-link-0":"themify-link-0","themify-link-1":"themify-link-1","themify-link-2":"themify-link-2","themify-link-3":"themify-link-3","themify-link-4":"themify-link-4"}";s:23:"setting-link_field_hash";s:1:"5";s:30:"setting-page_builder_is_active";s:6:"enable";s:46:"setting-page_builder_animation_parallax_scroll";s:6:"mobile";s:4:"skin";s:85:"https://themify.me/demo/themes/grido/wp-content/themes/grido/themify/img/non-skin.gif";}<?php $themify_data = unserialize( ob_get_clean() );

	// fix the weird way "skin" is saved
	if( isset( $themify_data['skin'] ) ) {
		$parsed_skin = parse_url( $themify_data['skin'], PHP_URL_PATH );
		$basedir_skin = basename( dirname( $parsed_skin ) );
		$themify_data['skin'] = trailingslashit( get_template_directory_uri() ) . 'skins/' . $basedir_skin . '/style.css';
	}

	themify_set_data( $themify_data );
	
}
themify_do_demo_import();